@@ -14,16 +14,20 @@ class ProgPercent(Prog):
 
     Keyword Arguments:
         iterations (int): number of iterations of the computation
-        width (int): width of the progress bar in characters
-        track_time (bool): prints elapsed time and estimated time left
-        stream: takes 1 for stdout, 2 for stderr, or given stream object
-        title (str): A title for the percent indicator
+        track_time (bool): default True. Prints elapsed time when loop has finished
+        stream (int): default 2. Takes 1 for stdout, 2 for stderr, or given stream object
+        title (str): default ''. A title for the progress bar
+        monitor (bool): default False. Monitors CPU and memory usage if True 
+            (requires 'psutil' package).
 
     """
-    def __init__(self, iterations, track_time=True, stream=2, title=''):
-        Prog.__init__(self, iterations, track_time, stream, title)
+    def __init__(self, iterations, track_time=True, stream=2, title='', monitor=False):
+        Prog.__init__(self, iterations, track_time, stream, title, monitor)
         self.perc = 0
         self._print_update()
+        if monitor:
+            self.process.cpu_percent()
+            self.process.memory_percent()
 
     def _print_update(self):
         """Prints formatted integer percentage and tracked time to the screen."""
